@@ -1,7 +1,7 @@
 package Bio::Graphics::Browser2::PluginSet;
 # API for using plugins
 
-#  $Id: PluginSet.pm 24031 2010-10-25 19:00:33Z lstein $
+#  $Id: PluginSet.pm 24345 2011-01-10 07:52:07Z lstein $
 
 use strict;
 use Bio::Graphics::Browser2;
@@ -17,6 +17,10 @@ sub new {
 
   warn "initializing plugins with $config..." if DEBUG;
   my @plugins = shellwords($config->plugins);
+  # only one authorization plugin allowed, from globals
+  if (my $auth = $config->auth_plugin) {
+      unshift @plugins,$auth; # first one
+  }
   warn "PLUGINS = @plugins" if DEBUG;
 
  PLUGIN:
@@ -40,11 +44,11 @@ sub new {
     }
     warn $@ if !$plugin_list{$plugin} && $@ =~ /^Can\'t locate/;
   }
-
-  return bless {
+  my $self = bless {
 		config        => $config,
 		plugins       => \%plugin_list
 	       },ref $package || $package;
+  return $self;
 }
 
 sub config        { shift->{config}         }
@@ -66,6 +70,13 @@ sub language {
   $d;
 }
 
+sub auth_plugin {
+    my $self = shift;
+    my @a    = grep {$_->type eq 'authenticator'} values %{$self->{plugins}};
+    return unless @a;
+    return $a[0];
+}
+
 sub configure {
   my $self     = shift;
   my $render   = shift;
@@ -114,6 +125,11 @@ sub configure {
 	  $p->page_settings->{features}{$setting_name}{visible} = 1;
       }
 
+      if ($p->type eq 'authenticator') {
+	  my $source = $self->config;
+	  $source->set_authenticator($p);
+	  $source->set_username($render->session->username);
+      }
     };
 
     warn "$name: $@" if $@;
